summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/designer/outputwindow.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-14 16:45:05 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-14 16:45:05 +0000
commit48d4a26399959121f33d2bc3bfe51c7827b654fc (patch)
tree5ae5e6e00d3ba330b7b8be9bc097154b6bc739e8 /kdevdesigner/designer/outputwindow.h
parent7e701ace6592d09e1f2c0cf28c7d6d872d78f4f5 (diff)
downloadtdevelop-48d4a26399959121f33d2bc3bfe51c7827b654fc.tar.gz
tdevelop-48d4a26399959121f33d2bc3bfe51c7827b654fc.zip
TQt4 port kdevelop
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdevelop@1236710 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdevdesigner/designer/outputwindow.h')
-rw-r--r--kdevdesigner/designer/outputwindow.h23
1 files changed, 12 insertions, 11 deletions
diff --git a/kdevdesigner/designer/outputwindow.h b/kdevdesigner/designer/outputwindow.h
index 6e9ed4a1..9e1a5aaf 100644
--- a/kdevdesigner/designer/outputwindow.h
+++ b/kdevdesigner/designer/outputwindow.h
@@ -1,15 +1,15 @@
/**********************************************************************
** Copyright (C) 2001 Trolltech AS. All rights reserved.
**
** This file is part of Qt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-** information about Qt Commercial License Agreements.
+** information about TQt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
@@ -36,18 +36,18 @@ struct DesignerOutputDock;
class TQTextEdit;
class TQListView;
-class ErrorItem : public QListViewItem
+class ErrorItem : public TQListViewItem
{
public:
enum Type { Error, Warning };
- ErrorItem( TQListView *parent, TQListViewItem *after, const TQString &message, int line,
+ ErrorItem( TQListView *tqparent, TQListViewItem *after, const TQString &message, int line,
const TQString &locationString, TQObject *locationObject );
void paintCell( TQPainter *, const TQColorGroup & cg,
- int column, int width, int alignment );
+ int column, int width, int tqalignment );
- void setRead( bool b ) { read = b; repaint(); }
+ void setRead( bool b ) { read = b; tqrepaint(); }
TQObject *location() const { return object; }
int line() const { return text( 2 ).toInt(); }
@@ -59,12 +59,13 @@ private:
};
-class OutputWindow : public QTabWidget
+class OutputWindow : public TQTabWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
- OutputWindow( TQWidget *parent );
+ OutputWindow( TQWidget *tqparent );
~OutputWindow();
void setErrorMessages( const TQStringList &errors, const TQValueList<uint> &lines,
@@ -79,7 +80,7 @@ public:
void shuttingDown();
- static QtMsgHandler oldMsgHandler;
+ static TQtMsgHandler oldMsgHandler;
private slots:
void currentErrorChanged( TQListViewItem *i );
@@ -1,15 +1,15 @@
** Copyright (C) 2001 Trolltech AS. All rights reserved.
**
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the